@@ -77,11 +77,10 @@ async def format_info(
     str
         Simple info text.
     """
+    cog_name = qualified_name.lower()
+    current = _get_current_vers(cog_version, qualified_name)
     try:
         latest = await _get_latest_vers()
-        current = _get_current_vers(cog_version, qualified_name)
-
-        cog_name = qualified_name.lower()
 
         cog_updated = (
             GREEN_CIRCLE if current.cogs.get(cog_name) >= latest.cogs.get(cog_name) else RED_CIRCLE
@@ -90,9 +89,8 @@ async def format_info(
         red_updated = GREEN_CIRCLE if current.red >= latest.red else RED_CIRCLE
     except Exception:  # anything and everything, eg aiohttp error or version parsing error
         log.warning("Unable to parse versions.", exc_info=True)
-        cog_updated = "Unknown"
-        utils_updated = "Unknown"
-        red_updated = "Unknown"
+        cog_updated, utils_updated, red_updated = "Unknown", "Unknown", "Unknown"
+        latest = UnknownVers({cog_name: "Unknown"})
 
     start = f"{qualified_name} by Vexed.\n<https://github.com/Vexed01/Vex-Cogs>\n\n"
     versions = [
@@ -137,7 +135,7 @@ async def out_of_date_check(cogname: str, currentver: str) -> None:
         )
         # really doesn't matter if this fails so fine with debug level
         return
-    if VersionInfo.from_str(currentver) < VersionInfo.from_str(vers.cogs.get(cogname)):
+    if VersionInfo.from_str(currentver) < vers.cogs.get(cogname):
         log.warning(
             f"Your {cogname} cog, from Vex, is out of date. You can update your cogs with the "
             "'cog update' command in Discord."
@@ -152,6 +150,12 @@ class Vers(NamedTuple):
     red: VersionInfo
 
 
+class UnknownVers(NamedTuple):
+    cogs: Dict[str, str]
+    utils: str = "Unknown"
+    red: str = "Unknown"
+
+
 @cached(cog_ver_cache)  # ttl is 5 mins
 async def _get_latest_vers() -> Vers:
     data: dict
